AFRL labeling Collection Info (sarpy.annotation.afrl_elements.CollectionInfo)
=============================================================================

.. automodule:: sarpy.annotation.afrl_elements.CollectionInfo
    :members:
    :show-inheritance:
    :inherited-members:
